@@ -41,7 +41,7 @@ class ELISALIB_EXPORT AudioWrapper : public QObject
                READ status
                NOTIFY statusChanged)
 
-    Q_PROPERTY(QMediaPlayer::State playbackState
+    Q_PROPERTY(QMediaPlayer::PlaybackState playbackState
                READ playbackState
                NOTIFY playbackStateChanged)
 
@@ -68,23 +68,23 @@ public:
 
     ~AudioWrapper() override;
 
-    bool muted() const;
+    [[nodiscard]] bool muted() const;
 
-    qreal volume() const;
+    [[nodiscard]] qreal volume() const;
 
-    QUrl source() const;
+    [[nodiscard]] QUrl source() const;
 
-    QMediaPlayer::MediaStatus status() const;
+    [[nodiscard]] QMediaPlayer::MediaStatus status() const;
 
-    QMediaPlayer::State playbackState() const;
+    [[nodiscard]] QMediaPlayer::PlaybackState playbackState() const;
 
-    QMediaPlayer::Error error() const;
+    [[nodiscard]] QMediaPlayer::Error error() const;
 
-    qint64 duration() const;
+    [[nodiscard]] qint64 duration() const;
 
-    qint64 position() const;
+    [[nodiscard]] qint64 position() const;
 
-    bool seekable() const;
+    [[nodiscard]] bool seekable() const;
 
 Q_SIGNALS:
 
@@ -96,7 +96,7 @@ Q_SIGNALS:
 
     void statusChanged(QMediaPlayer::MediaStatus status);
 
-    void playbackStateChanged(QMediaPlayer::State state);
+    void playbackStateChanged(QMediaPlayer::PlaybackState state);
 
     void errorChanged(QMediaPlayer::Error error);
 
@@ -149,7 +149,7 @@ private Q_SLOTS:
 private:
     void savePosition(qint64 position);
 
-    void playerStateSignalChanges(QMediaPlayer::State newState);
+    void playerStateSignalChanges(QMediaPlayer::PlaybackState newState);
 
     void mediaStatusSignalChanges(QMediaPlayer::MediaStatus newStatus);
 
