@@ -60,8 +60,7 @@ public:
                    Qt::SortOrder sortOrder, QVector<QString> sortOrderNames,
                    QUrl fallbackItemIcon,
                    ViewManager::DelegateUseSecondaryText showSecondaryTextOnDelegates,
-                   ViewManager::ViewCanBeRated viewCanBeRated,
-                   ViewManager::IsTreeModelType isTreeModel)
+                   ViewManager::ViewCanBeRated viewCanBeRated)
         : mMainTitle(std::move(mainTitle))
         , mMainImage(std::move(mainImage))
         , mViewPresentationType(viewPresentationType)
@@ -71,7 +70,6 @@ public:
         , mFallbackItemIcon(std::move(fallbackItemIcon))
         , mShowSecondaryTextOnDelegates(showSecondaryTextOnDelegates)
         , mViewCanBeRated(viewCanBeRated)
-        , mIsTreeModel(isTreeModel)
         , mSortRole(sortRole)
         , mSortRoles(std::move(sortRoles))
         , mSortRoleNames(std::move(sortRoleNames))
@@ -90,7 +88,6 @@ public:
                    QUrl fallbackItemIcon,
                    ViewManager::DelegateUseSecondaryText showSecondaryTextOnDelegates,
                    ViewManager::ViewCanBeRated viewCanBeRated,
-                   ViewManager::IsTreeModelType isTreeModel,
                    QUrl pathFilter)
         : mMainTitle(std::move(mainTitle))
         , mMainImage(std::move(mainImage))
@@ -101,7 +98,6 @@ public:
         , mFallbackItemIcon(std::move(fallbackItemIcon))
         , mShowSecondaryTextOnDelegates(showSecondaryTextOnDelegates)
         , mViewCanBeRated(viewCanBeRated)
-        , mIsTreeModel(isTreeModel)
         , mDataFilter{{DataTypes::FilePathRole, std::move(pathFilter)}}
         , mIsValid(true)
     {
@@ -117,15 +113,13 @@ public:
                    Qt::SortOrder sortOrder, QVector<QString> sortOrderNames,
                    ViewManager::AlbumCardinality albumCardinality,
                    ViewManager::AlbumViewStyle albumViewStyle,
-                   ViewManager::RadioSpecificStyle radioSpecificStyle,
-                   ViewManager::IsTreeModelType isTreeModel)
+                   ViewManager::RadioSpecificStyle radioSpecificStyle)
         : mMainTitle(std::move(mainTitle))
         , mMainImage(std::move(mainImage))
         , mViewPresentationType(viewPresentationType)
         , mModelType(modelType)
         , mFilterType(filterType)
         , mDataType(dataType)
-        , mIsTreeModel(isTreeModel)
         , mSortRole(sortRole)
         , mSortRoles(std::move(sortRoles))
         , mSortRoleNames(std::move(sortRoleNames))
@@ -176,8 +170,7 @@ public:
                    Qt::SortOrder sortOrder, QVector<QString> sortOrderNames,
                    ViewManager::AlbumCardinality albumCardinality,
                    ViewManager::AlbumViewStyle albumViewStyle,
-                   ViewManager::RadioSpecificStyle radioSpecificStyle,
-                   ElisaUtils::IconUseColorOverlay iconUseColorOverlay)
+                   ViewManager::RadioSpecificStyle radioSpecificStyle)
         : mMainTitle(std::move(mainTitle))
         , mMainImage(std::move(mainImage))
         , mViewPresentationType(viewPresentationType)
@@ -193,7 +186,6 @@ public:
         , mAlbumCardinality(albumCardinality)
         , mAlbumViewStyle(albumViewStyle)
         , mRadioSpecificStyle(radioSpecificStyle)
-        , mIconUseColorOverlay(iconUseColorOverlay)
         , mIsValid(true)
     {
         mDataFilter = {{DataTypes::DatabaseIdRole, databaseId}};
@@ -203,7 +195,7 @@ public:
         return mMainTitle == other.mMainTitle && mMainImage == other.mMainImage &&
                 mSecondaryTitle == other.mSecondaryTitle && mViewPresentationType == other.mViewPresentationType &&
                 mModelType == other.mModelType && mFilterType == other.mFilterType &&
-                mDataType == other.mDataType && mIsTreeModel == other.mIsTreeModel && mFallbackItemIcon == other.mFallbackItemIcon &&
+                mDataType == other.mDataType && mFallbackItemIcon == other.mFallbackItemIcon &&
                 mShowSecondaryTextOnDelegates == other.mShowSecondaryTextOnDelegates && mViewCanBeRated == other.mViewCanBeRated &&
                 mSortRole == other.mSortRole && mSortRoles == other.mSortRoles && mSortRoleNames == other.mSortRoleNames &&
                 mSortOrder == other.mSortOrder && mSortOrderNames == other.mSortOrderNames &&
@@ -216,7 +208,7 @@ public:
         return mMainTitle != other.mMainTitle || mMainImage != other.mMainImage ||
                 mSecondaryTitle != other.mSecondaryTitle || mViewPresentationType != other.mViewPresentationType ||
                 mModelType != other.mModelType || mFilterType != other.mFilterType ||
-                mDataType != other.mDataType || mIsTreeModel != other.mIsTreeModel || mFallbackItemIcon != other.mFallbackItemIcon ||
+                mDataType != other.mDataType || mFallbackItemIcon != other.mFallbackItemIcon ||
                 mShowSecondaryTextOnDelegates != other.mShowSecondaryTextOnDelegates || mViewCanBeRated != other.mViewCanBeRated ||
                 mSortRole != other.mSortRole || mSortRoles != other.mSortRoles || mSortRoleNames != other.mSortRoleNames ||
                 mSortOrder != other.mSortOrder || mSortOrderNames != other.mSortOrderNames ||
@@ -247,8 +239,6 @@ public:
 
     ViewManager::ViewCanBeRated mViewCanBeRated = ViewManager::ViewHideRating;
 
-    ViewManager::IsTreeModelType mIsTreeModel = ViewManager::IsFlatModel;
-
     int mSortRole = Qt::DisplayRole;
 
     QVector<int> mSortRoles = {Qt::DisplayRole};
@@ -269,8 +259,6 @@ public:
 
     DataTypes::MusicDataType mDataFilter;
 
-    ElisaUtils::IconUseColorOverlay mIconUseColorOverlay = ElisaUtils::UseColorOverlay;
-
     bool mUseSecondTitle = false;
 
     bool mIsValid = false;
@@ -295,10 +283,6 @@ class ELISALIB_EXPORT ViewsListData : public QObject
                WRITE setDatabase
                NOTIFY databaseChanged)
 
-    Q_PROPERTY(bool isFullyInitialized
-               READ isFullyInitialized
-               NOTIFY isFullyInitializedChanged)
-
 public:
     explicit ViewsListData(QObject *parent = nullptr);
 
@@ -318,15 +302,11 @@ public:
 
     [[nodiscard]] bool useSecondTitle(int index) const;
 
-    [[nodiscard]] ElisaUtils::IconUseColorOverlay iconUseColorOverlay(int index) const;
-
     [[nodiscard]] qulonglong databaseId(int index) const;
 
     [[nodiscard]] bool defaultEntry(int index) const;
 
-    [[nodiscard]] int indexFromEmbeddedDatabaseId(qulonglong databaseId) const;
-
-    [[nodiscard]] int indexFromEmbeddedName(const QString &name) const;
+    [[nodiscard]] ElisaUtils::PlayListEntryType dataType(int index) const;
 
     [[nodiscard]] ElisaUtils::PlayListEntryType embeddedCategory() const;
 
@@ -334,8 +314,6 @@ public:
 
     [[nodiscard]] DatabaseInterface* database() const;
 
-    [[nodiscard]] bool isFullyInitialized() const;
-
 Q_SIGNALS:
 
     void embeddedCategoryChanged();
@@ -360,8 +338,6 @@ Q_SIGNALS:
 
     void dataReset();
 
-    void isFullyInitializedChanged();
-
 public Q_SLOTS:
 
     void setEmbeddedCategory(ElisaUtils::PlayListEntryType aEmbeddedView);
@@ -386,6 +362,8 @@ public Q_SLOTS:
 
 private:
 
+    void clearEmbeddedItems();
+
     void refreshEmbeddedCategory();
 
     std::unique_ptr<ViewsListDataPrivate> d;
